=======
Authors
=======

Development Lead
----------------
* Joern Weissenborn <joern.weissenborn@gmail.com>
* Joris Snellenburg <j.snellenburg@gmail.com>

Contributors
------------
* Sebastian Weigand <s.weigand.phy@gmail.com>

Special Thanks
--------------
* Stefan Schuetz
* Sergey P. Laptenok

Supervision
--------------
* **dr. Ivo H.M. van Stokkum** <i.h.m.van.stokkum@vu.nl> (`University profile <https://research.vu.nl/en/persons/ihm-van-stokkum>`_)

Original publications
---------------------
1. Joris J. Snellenburg, Sergey Laptenok, Ralf Seger, Katharine M. Mullen, Ivo H. M. van Stokkum. "Glotaran: A Java-Based Graphical User Interface for the R Package TIMP". Journal of Statistical Software (2012), Volume 49, Number 3, Pages: 1–22. URL https://dx.doi.org/10.18637/jss.v049.i03
2. Katharine M. Mullen, Ivo H. M. van Stokkum. "TIMP: An R Package for Modeling Multi-way Spectroscopic Measurements". Journal of Statistical Software (2007), Volume 18, Number 3, Pages 1-46, ISSN 1548-7660. URL https://dx.doi.org/10.18637/jss.v018.i03
3. Ivo H. M. van Stokkum, Delmar S. Larsen, Rienk van Grondelle, "Global and target analysis of time-resolved spectra". Biochimica et Biophysica Acta (BBA) - Bioenergetics (2004), Volume 1657, Issues 2–3, Pages 82-104, ISSN 0005-2728. URL https://doi.org/10.1016/j.bbabio.2004.04.011
